"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var axios_1 = require("axios");
var Client_1 = require("./Client");
var Response_1 = require("./Response");
/**
 * AxiosClient
 */
var AxiosClient = /** @class */ (function (_super) {
    tslib_1.__extends(AxiosClient, _super);
    /**
     * Constructor
     *
     * @param host
     * @param version
     * @param timeout
     * @param retryMap
     * @param overrideQueries
     * @param cache
     */
    function AxiosClient(host, version, timeout, retryMap, overrideQueries, cache) {
        var _this = _super.call(this, version, retryMap) || this;
        _this.host = host;
        _this.timeout = timeout;
        _this.cache = cache;
        _this.overrideQueries = overrideQueries;
        _this.cancelToken = axios_1["default"].CancelToken.source();
        return _this;
    }
    /**
     * Get
     *
     * @param url
     * @param method
     * @param credentials
     * @param parameters
     * @param data
     *
     * @return {Promise<Response>}
     */
    AxiosClient.prototype.get = function (url, method, credentials, parameters, data) {
        if (parameters === void 0) { parameters = {}; }
        if (data === void 0) { data = {}; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var that;
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                that = this;
                url = url.replace(/^\/*|\/*$/g, "");
                url = "/" + (this.version + "/" + url).replace(/^\/*|\/*$/g, "");
                method = method.toLowerCase();
                if ("get" === method &&
                    this.overrideQueries) {
                    this.abort();
                }
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var headers = "get" == method
                            ? {}
                            : {
                                "Content-Encoding": "gzip",
                                "Content-Type": "application/json"
                            };
                        //noinspection TypeScriptValidateTypes
                        axios_1["default"]
                            .request({
                            url: url + "?" + Client_1.Client.objectToUrlParameters(tslib_1.__assign({}, credentials, parameters)),
                            data: data,
                            headers: headers,
                            method: method,
                            baseURL: that.host.replace(/\/*$/g, ""),
                            timeout: that.timeout,
                            cancelToken: _this.cancelToken.token,
                            transformRequest: [function (data) { return JSON.stringify(data); }]
                        })
                            .then(function (axiosResponse) {
                            var response = new Response_1.Response(axiosResponse.status, axiosResponse.data);
                            return resolve(response);
                        })["catch"](function (thrown) { return reject(thrown); });
                    })];
            });
        });
    };
    /**
     * Abort current request
     * And regenerate the cancellation token
     */
    AxiosClient.prototype.abort = function () {
        this.cancelToken.cancel();
        this.cancelToken = axios_1["default"].CancelToken.source();
    };
    return AxiosClient;
}(Client_1.Client));
exports.AxiosClient = AxiosClient;
